#!/bin/bash
# detects tickets that expire today.
# or really, finds tickets opened on a specific date, in 
# a provided group, w/ incident area set to a  
# specific incident area. ("Practice Protection/Data Retention/Hard Drive" in this case)
# and priority=Negotiated ("QBE.EQ.Priority=1 in the wget's URL)
# Your needs may differ.  Medium priority=3.

# This plug-in needs a regualr java/browser session ID. 
#  Put the session values in SD-Browser-session.txt

# You'll need "lynx", a console based browser, installed.
# You may need to specify a domain in the username.
# If so, use double back slashes. .
#  Ex:  USER=mydomain\\username

USER=username
PASS=password
STATE_OK=0
STATE_WARNING=1
STATE_CRITICAL=2
STATE_UNKNOWN=3
STATE_DEPENDENT=4
cd /usr/local/nagios/libexec

# Name of temporary file used during operations. 
# Keep it unique across different plugins. 
TMP="output-$1-expiring.html"

# Describe or name the type of check.  This is put in the response.
DESC="HDR wipe"

if [ -z $1 ]
then
	echo -e "Error.  Usage: check-sd-expiring.sh groupname critnum \n\tAnything below critical is a warning level"
	exitstatus=$STATE_UNKNOWN
	exit $exitstatus
fi
if [ -z $2 ]
then
	echo -e "Error.  Usage: check-sd-expiring.sh groupname critnum \n\tAnything below critical is a warning level"
	exitstatus=$STATE_UNKNOWN
	exit $exitstatus
fi
source ./SD-Browser-session.txt 


if [ -z "$SID" ] ; then
        # we got an empty string
	echo "UNKNOWN: - Session info missing"
        exitstatus=$STATE_UNKNOWN
	exit $exitstatus;
fi


date=`/usr/local/nagios/libexec/6daysago.php`;
#date="09/20/2011"

wget -T5 -t2 -q -O $TMP --user=$USER --password=$PASS \
 http://$server/CAisd/$pdmweb.exe?SID=$SID\&FID=$FID\&OP=SEARCH\&FACTORY=in\&QBE.IN.group.last_name=$1\&QBE.EQ.priority=1\&QBE.EQ.active=1\&QBE.EQ.category=pcat%3A410761\&QBE.GE.open_date=$date\&QBE.LE.open_date=$date\&KEEP.isHierSearch=0\&XTRA_QBE=QBE.IN.category.sym%3DPractice%20Protection.Data%20Retention.Hard%20Drive%25

# check that wget worked
if [ "$?" -ne 0 ] ; then
	echo "UNKNOWN: - SD Engine Down?"
        exitstatus=$STATE_UNKNOWN
	exit $exitstatus;
fi

#Is it a redirect/bad session?  1=yes 0=no
output=`grep -a OnLoad\=\'do_submit $TMP|wc -l`
if [ "$output" -eq 1 ]; then
        echo "UNKNOWN: - Redirect Received"
	rm $TMP
        exitstatus=$STATE_UNKNOWN
        exit $exitstatus;
fi
output=`grep -a noconnect $TMP|wc -l`
if [ "$output" -eq 1 ]; then
        echo "UNKNOWN: - No valid connection to server"
	rm $TMP
        exitstatus=$STATE_UNKNOWN
        exit $exitstatus;
fi

output=`grep -a USERNAME $TMP|grep User\ Name|wc -l`
if [ "$output" -gt 0 ]; then
        echo "UNKNOWN: - Login prompt received."
	rm $TMP
        exitstatus=$STATE_UNKNOWN
        exit $exitstatus;
fi

output=`grep Authentication\ failure $TMP -a|wc -l`
if [ "$output" -gt 0 ]; then
        echo "UNKNOWN: - Login prompt received."
	rm $TMP
        exitstatus=$STATE_UNKNOWN
        exit $exitstatus;
fi

output=`grep AHD04 $TMP -a|wc -l`
if [ "$output" -gt 0 ]; then
        echo "UNKNOWN: - Invalid session ID in use."
	rm $TMP
        exitstatus=$STATE_UNKNOWN
        exit $exitstatus;
fi


# Remove formatting and other cruft stuff.
# This is what will be mailed in the notification also.
grep -a rs.data $TMP |sed -e 's/rs.data//' | tr -d \(\'\)\; | sed -e 's/ref_num_style//' | tr -d \\r |grep -a -v date_to_string >$TMP.clean

# check the "clean" file for non-zero length (no search result/rs.data probably)
FILESIZE=$(stat -c%s "$TMP.clean")
if [ "$FILESIZE" -eq 0 ] ; then
        echo "OK: No expiring $DESC tickets today.|open=0"
        exitstatus=$STATE_OK
	rm -fr $TMP*
        exit $exitstatus;
fi

# At this point, data is found in $TMP so we have tickets.  
# count "rs.data" lines in $TMP 
# there are 17 lines per ticket it seems 
# so divide lines /17 = total tickets
lines=`grep -a rs.data $TMP | wc -l`
open=`echo "$lines/17"|bc`
# we're done looking at the html output
rm -fr $TMP


if [ "$open" -ge $2 ] ; then
	echo -e "ALERT: $open $DESC ticket(s) expire today.|open=$open"
	cat $TMP.clean
	rm $TMP.clean
	exitstatus=$STATE_CRITICAL
else 
	echo "WARNING: $open $DESC ticket(s) in $3 expire today.|open=$open"
	cat $TMP.clean
	rm $TMP.clean
	exitstatus=$STATE_WARNING
fi

exit $exitstatus;
