#!/bin/bash
# detects open tickets with a medium status
# in a specified group (named by the UUID on the command line).  
# Use this when the queue name in Service Desk contains spaces or 
# odd characters that break the check-sdgroup-byname plug-in.
# Get the group's UUID by using the "Show Filter" button in Service Desk.

#If you need to specify a domain in the username,
#use double back slashes. 
#  Ex:  USER=mydomain\\username 
USER=username
PASS=password

STATE_OK=0
STATE_WARNING=1
STATE_CRITICAL=2
STATE_UNKNOWN=3
STATE_DEPENDENT=4

cd /usr/local/nagios/var/SDchecks/groups
TMP="output-$1-group-by-uuid.html"

if [ -z $1 ]
then
	echo "Usage: check-group.sh groupnum critnum Description \ anything below critical is a warning level"
	exitstatus=$STATE_UNKNOWN
	exit $exitstatus
fi
if [ -z $2 ]
then
	echo "Usage: check-sdgroup-by-uuid.sh groupnum critnum Description \ anything below critical is a warning level"
	exitstatus=$STATE_UNKNOWN
	exit $exitstatus
fi
if [ -z $3 ]
then
	echo "Usage: check-sdgroup-by-uuid.sh groupnum critnum Description  \ anything below critical is a warning level"
	exitstatus=$STATE_UNKNOWN
	exit $exitstatus
fi

# this check needs PDA session info
source ../SD-PDA-session.txt

if [ -z "$SID" ] ; then
        # we got an empty string
	echo "UNKNOWN: - Session info missing"
        exitstatus=$STATE_UNKNOWN
	exit $exitstatus;
fi


wget -T 6 -t3 -q -O $TMP --user=$USER --password=$PASS http://$server/CAisd/$pdmweb.exe?SID=$SID+FID=$FID+OP=SEARCH+QBE.EQ.status=OP+QBE.EQ.priority=3+FACTORY=cr+KEEP.where_clause=group.id%3DU%27$1%27

# check that wget worked.  Error levels are:
#1   Generic error code.
#2   Parse error—for instance, when parsing command-line options, the ‘.wgetrc’ or ‘.netrc’...
#3   File I/O error.
#4   Network failure.
#5   SSL verification failure.
#6   Username/password authentication failure.
#7   Protocol errors.
#8   Server issued an error response. 


STATUS=$?
if [ "$STATUS" -eq 6 ] ; then
	echo "UNKNOWN: - Authentication not accepted"
        exitstatus=$STATE_UNKNOWN
	exit $exitstatus;
fi

if [ "$STATUS" -ne 0 ] ; then
	echo "UNKNOWN: - SD Engine down? ($STATUS)"
        exitstatus=$STATE_UNKNOWN
	exit $exitstatus;
fi


#Is it a redirect/bad session?  1=yes 0=no
output=`grep -a OnLoad\=\'do_submit $TMP|wc -l`
if [ "$output" -eq 1 ]; then
        echo "UNKNOWN: - Redirect Received"
	rm $TMP
        exitstatus=$STATE_UNKNOWN
        exit $exitstatus;
fi
output=`grep -a noconnect $TMP|wc -l`
if [ "$output" -eq 1 ]; then
        echo "UNKNOWN: - No valid connection to server"
	rm $TMP
        exitstatus=$STATE_UNKNOWN
        exit $exitstatus;
fi

output=`grep -a USERNAME $TMP|grep User\ Name|wc -l`
if [ "$output" -gt 0 ]; then
        echo "UNKNOWN: - Login prompt received."
	rm $TMP
        exitstatus=$STATE_UNKNOWN
        exit $exitstatus;
fi

output=`grep Authentication\ failure $TMP -a|wc -l`
if [ "$output" -gt 0 ]; then
        echo "UNKNOWN: - Login prompt received."
	rm $TMP
        exitstatus=$STATE_UNKNOWN
        exit $exitstatus;
fi

output=`grep Parse\ error $TMP -a|wc -l`
if [ "$output" -gt 0 ]; then
        echo "UNKNOWN: - Parse Error received."
	rm $TMP
        exitstatus=$STATE_UNKNOWN
        exit $exitstatus;
fi

# find the line with query matches count, and cut, and remove
# non digits
open=`grep -a title2 $TMP| cut -d ">" -f2| sed 's/[^0-9]*//g'`
exitstatus=$STATE_OK

if [ -z "$open" ] ; then 
        message="OK: Empty box. 0 tickets for $3|open=0\n";
        exitstatus=$STATE_OK


elif  [ "$open" -eq "0" ] ;  then
	message="OK: $3 has 0 tickets with open status.|open=$open\n"
	exitstatus=$STATE_OK

elif [ "$open" -ge "$2" ] ; then
	message="ALERT: $open open ticket(s) for $3.|open=$open\n `lynx -dump -nolist $TMP|grep -v Search\ Request`"
	exitstatus=$STATE_CRITICAL

# this is where warning level could be set ( count is < critical number)
else  message="OK:  $open open ticket(s) for $3 detected|open=$open\n" 
fi

echo -e "$message"
exit $exitstatus;

